"use strict";
class ForceDeleteExtension {
    constructor() {
        this.LOOP_INTERVAL_TIME = 100;
        this.EXPLICIT_TARGET_SELECTORS = [
            // S3 ---
            '.delete-bucket-actions__input>input',
            // VPC ---
            'div[data-id="confirmation-modal-input"]>input',
            // IAM ---
            'div[data-testid="delete-user-input-test1"]>input',
            'div[data-testid="roles-delete-modal-input"]>input',
            'div[data-testid="policies-delete-modal-input"]>input',
            'div[data-testid="policies-from-role-delete-modal-input"]>input',
            // Firehose ---
            'div[data-hook="DELETE_CONFIRMATION_INPUT"]>input',
            // RDS ---
            'div[data-testid="delete-protection-input"]>input'
        ];
        this.OVERRIDDEN_TARGET_VALUES = [
            {
                target: 'div[data-testid="delete-protection-input"]>input',
                value: 'delete me'
            }
        ];
        this.IMPLICIT_TARGET_PLACEHOLDERS = [
            'delete',
            'delete me',
            'confirm',
            'permanently delete'
        ];
        this.startLoop = () => {
            setInterval(this.process.bind(this), this.LOOP_INTERVAL_TIME);
        };
        this.process = () => this.applyDeleteMessages(this.findTargets());
        //
        // Target Element Finder ---
        this.findTargets = () => [
            ...this.findExplicitTargets(),
            ...this.findImplicitTargets()
        ];
        this.findExplicitTargets = () => this.EXPLICIT_TARGET_SELECTORS
            .map(this.findTargetElements.bind(this))
            .reduce((prev, curr) => ([...prev, ...curr]), [])
            .filter((v) => v !== null &&
            v instanceof HTMLInputElement)
            .filter((v) => !v.disabled &&
            v.value.length < 1);
        this.findImplicitTargets = () => this.findTargetElements('input')
            .filter((v) => v !== null &&
            v instanceof HTMLInputElement)
            .filter((v) => !v.disabled &&
            v.value.length < 1 &&
            this.IMPLICIT_TARGET_PLACEHOLDERS.includes(v.placeholder.toLowerCase()));
        this.findTargetElements = (targetSelector) => [...document.querySelectorAll(targetSelector)];
        //
        // Delete-safe Message Applier ---
        this.applyDeleteMessages = (elements) => elements.forEach(this.applyDeleteMessage.bind(this));
        this.applyDeleteMessage = (element) => {
            element.classList.add('__force_deleted'); // Play autocomplete animation
            element.value = this.calculateValue(element);
            element.dispatchEvent(new Event('input', {
                bubbles: true
            }));
        };
        //
        // Value Calculator ---
        this.calculateValue = (element) => {
            var _a, _b;
            return (_b = (_a = this.findOverriddenValue(element)) !== null && _a !== void 0 ? _a : this.findPlaceholderValue(element)) !== null && _b !== void 0 ? _b : 'delete';
        };
        this.findOverriddenValue = (element) => {
            var _a;
            return (_a = this.OVERRIDDEN_TARGET_VALUES
                .find((v) => [...document.querySelectorAll(v.target)].includes(element))) === null || _a === void 0 ? void 0 : _a.value;
        };
        this.findPlaceholderValue = (element) => element.placeholder.length > 0
            ? element.placeholder
            : undefined;
    }
}
//
// Main ---
new ForceDeleteExtension()
    .startLoop();
